@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Data Visualization module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include "qsurface3dseries_p.h"
 #include "surface3dcontroller_p.h"
@@ -83,7 +57,7 @@ QT_BEGIN_NAMESPACE
  * \inqmlmodule QtDataVisualization
  * \since QtDataVisualization 1.0
  * \ingroup datavisualization_qml
- * \instantiates QSurface3DSeries
+ * \nativetype QSurface3DSeries
  * \inherits Abstract3DSeries
  * \brief Represents a data series in a 3D surface graph.
  *
@@ -165,6 +139,12 @@ QT_BEGIN_NAMESPACE
  * file name is set.
  */
 
+/*!
+ * \qmlproperty color Surface3DSeries::wireframeColor
+ * \since 6.3
+ *
+ * The color used to draw the gridlines of the surface wireframe.
+ */
 
 /*!
  * \enum QSurface3DSeries::DrawFlag
@@ -398,6 +378,24 @@ QString QSurface3DSeries::textureFile() const
     return dptrc()->m_textureFile;
 }
 
+/*!
+ * \property QSurface3DSeries::wireframeColor
+ * \since 6.3
+ *
+ * \brief The color for the surface wireframe.
+ */
+void QSurface3DSeries::setWireframeColor(const QColor &color)
+{
+    if (dptr()->m_wireframeColor != color) {
+        dptr()->setWireframeColor(color);
+        emit wireframeColorChanged(color);
+    }
+}
+
+QColor QSurface3DSeries::wireframeColor() const
+{
+    return dptrc()->m_wireframeColor;
+}
 /*!
  * \internal
  */
@@ -420,7 +418,8 @@ QSurface3DSeriesPrivate::QSurface3DSeriesPrivate(QSurface3DSeries *q)
     : QAbstract3DSeriesPrivate(q, QAbstract3DSeries::SeriesTypeSurface),
       m_selectedPoint(Surface3DController::invalidSelectionPosition()),
       m_flatShadingEnabled(true),
-      m_drawMode(QSurface3DSeries::DrawSurfaceAndWireframe)
+      m_drawMode(QSurface3DSeries::DrawSurfaceAndWireframe),
+      m_wireframeColor(Qt::black)
 {
     m_itemLabelFormat = QStringLiteral("@xLabel, @yLabel, @zLabel");
     m_mesh = QAbstract3DSeries::MeshSphere;
@@ -553,4 +552,11 @@ void QSurface3DSeriesPrivate::setTexture(const QImage &texture)
         static_cast<Surface3DController *>(m_controller)->updateSurfaceTexture(qptr());
 }
 
+void QSurface3DSeriesPrivate::setWireframeColor(const QColor &color)
+{
+    m_wireframeColor = color;
+    if (m_controller)
+        m_controller->markSeriesVisualsDirty();
+}
+
 QT_END_NAMESPACE
